==> codacy-plugins_2.12-7.5.0_play_2.7.jar: tool-cache/codacy-checkstyle/docs/description/JavadocMethod.md <==
Since Checkstyle 3.0

Checks the Javadoc of a method or constructor. By default, does not
check for unused throws. To allow documented
`java.lang.RuntimeException`s that are not declared, set property
allowUndeclaredRTE to true. The scope to verify is specified using the
`Scope` class and defaults to `Scope.PRIVATE`. To verify another scope,
set property scope to a different
[scope](https://checkstyle.org/property_types.html#scope).

Error messages about parameters and type parameters for which no param
tags are present can be suppressed by defining property
`allowMissingParamTags`. Error messages about exceptions which are
declared to be thrown, but for which no throws tag is present can be
suppressed by defining property `allowMissingThrowsTags`. Error messages
about methods which return non-void but for which no return tag is
present can be suppressed by defining property `allowMissingReturnTag`.

Javadoc is not required on a method that is tagged with the `@Override`
annotation. However under Java 5 it is not possible to mark a method
required for an interface (this was *corrected* under Java 6). Hence
Checkstyle supports using the convention of using a single
`{@inheritDoc}` tag instead of all the other tags.

Note that only inheritable items will allow the `{@inheritDoc}` tag to
be used in place of comments. Static methods at all visibilities,
private non-static methods and constructors are not inheritable.

For example, if the following method is implementing a method required
by an interface, then the Javadoc could be done as:

    /** {@inheritDoc} */
    public int checkReturnTag(final int aTagIndex,
                              JavadocTag[] aTags,
                              int aLineNo)

The classpath may need to be configured to locate the class information.
The classpath configuration is dependent on the mechanism used to invoke
Checkstyle.

==> codacy-plugins_2.12-8.5.7_play_2.7.jar: tool-cache/codacy-checkstyle/docs/description/JavadocMethod.md <==
Since Checkstyle 3.0

Checks the Javadoc of a method or constructor. By default, does not
check for unused throws. To allow documented
`java.lang.RuntimeException`s that are not declared, set property
allowUndeclaredRTE to true. The scope to verify is specified using the
`Scope` class and defaults to `Scope.PRIVATE`. To verify another scope,
set property scope to a different
[scope](https://checkstyle.org/property_types.html#scope).

Violates parameters and type parameters for which no param tags are
present can be suppressed by defining property `allowMissingParamTags`.
Violates exceptions which are declared to be thrown, but for which no
throws tag is present can be suppressed by defining property
`allowMissingThrowsTags`. Violates methods which return non-void but for
which no return tag is present can be suppressed by defining property
`allowMissingReturnTag`.

Javadoc is not required on a method that is tagged with the `@Override`
annotation. However under Java 5 it is not possible to mark a method
required for an interface (this was *corrected* under Java 6). Hence
Checkstyle supports using the convention of using a single
`{@inheritDoc}` tag instead of all the other tags.

Note that only inheritable items will allow the `{@inheritDoc}` tag to
be used in place of comments. Static methods at all visibilities,
private non-static methods and constructors are not inheritable.

For example, if the following method is implementing a method required
by an interface, then the Javadoc could be done as:

    /** {@inheritDoc} */
    public int checkReturnTag(final int aTagIndex,
                              JavadocTag[] aTags,
                              int aLineNo)

The classpath may need to be configured to locate the class information.
The classpath configuration is dependent on the mechanism used to invoke
Checkstyle.
